# This module mostly handles startup/config checks and then passes itself onwards

when isMainModule:
  import tables
  import os
  import modules/[blog, env, db, formatter, auth]

  let dataDir: string = "data"

  let settings = {
    "debug": boolEnvOrDefault("DEBUG", false),
    "logging": boolEnvOrDefault("NIMBLOG_LOG", true)
  }.toTable()

  if settings["debug"]:
    logPrint("Debug mode is enabled", "Warning")

  let dbSettings = {
    "schema_path": "schema.sql"
  }.toTable()

  logPrint("Starting website", "Main")

  if not dirExists(dataDir):
    logPrint("Created data directory", "Info")
    createDir(dataDir)

  if not createDb(dbSettings):
    logPrint("A database must be created before use", "Error")
    quit(QuitFailure)

  if not checkUser():
    logPrint("No user in database", "Warning")
    if not addUserInteractive():
      logPrint("An initial user must be created before use", "Error")
      quit(QuitFailure)

  try:
    runWebsite(settings=settings)
  except:
    logPrint("Could not run website", "Error")
